==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-VE/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Este usuario puede ingresar',
    'activated_disabled_help_text' => 'No puedes editar el estado de activación de tu propia cuenta.',
    'assets_user'       => 'Activos asignados a :name',
    'bulk_update_warn'	=> 'Estas a punto de editar las propiedades de :user_count usuarios. Por favor, ten en cuenta que no puedes cambiar los atributos de tus usuarios usando este formulario, y debes editar tu propio usuario individualmente.',
    'bulk_update_help'	=> 'Este formulario te permite actualizar múltiples usuarios a la vez. Sólo llena los campos que necesites cambiar. Cualquier campo dejado en blanco permanecerá sin cambios.',
    'current_assets'    => 'Activos actualmente asignados a este usuario',
    'clone'             => 'Clonar usuario',
    'contact_user'      => 'Contactar a :name',
    'edit'              => 'Editar Usuario',
    'filetype_info'     => 'Los tipos de archivos permitidos son png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, y rar.',
    'history_user'      => 'Historial para :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Haga clic aquí para restaurarlos.',
    'last_login'        => 'Último Inicio de Sesión',
    'ldap_config_text'  => 'Los parámetros de configuración LDAP pueden ser encontrados en Admin > Settings. La ubicación (opcional) seleccionada será establecida para todos los usuarios importados.',
    'print_assigned'    => 'Imprimir Todos los Asignados',
    'software_user'     => 'Software Asignado a :name',
    'send_email_help'   => 'Debe proporcionar una dirección de correo electrónico para este usuario para enviarle credenciales. Únicamente pueden enviarse credenciales por correo eléctronico durante la creación del usuario. Las contraseñas se almacenan en un hash de un solo sentido y no se pueden recuperar una vez guardadas.',
    'view_user'         => 'Ver Usuario :name',
    'usercsv'           => 'Archivo CSV',
    'two_factor_admin_optin_help' => 'Tus configuraciones de administrador actuales permiten cumplimiento selectivo de autenticación de dos factores.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA inscrito ',
    'two_factor_active'   => '2FA activo ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-VE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este usuario puede ingresar',
    'activated_disabled_help_text' => 'No puedes editar el estado de activación de tu propia cuenta.',
    'assets_user'       => 'Activos asignados a :name',
    'bulk_update_warn'	=> 'Estas a punto de editar las propiedades de :user_count usuarios. Por favor, ten en cuenta que no puedes cambiar los atributos de tus usuarios usando este formulario, y debes editar tu propio usuario individualmente.',
    'bulk_update_help'	=> 'Este formulario te permite actualizar múltiples usuarios a la vez. Sólo llena los campos que necesites cambiar. Cualquier campo dejado en blanco permanecerá sin cambios.',
    'current_assets'    => 'Activos actualmente asignados a este usuario',
    'clone'             => 'Clonar usuario',
    'contact_user'      => 'Contactar a :name',
    'edit'              => 'Editar Usuario',
    'filetype_info'     => 'Los tipos de archivos permitidos son png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, y rar.',
    'history_user'      => 'Historial para :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Haga clic aquí para restaurarlos.',
    'last_login'        => 'Último Inicio de Sesión',
    'ldap_config_text'  => 'Los parámetros de configuración LDAP pueden ser encontrados en Admin > Settings. La ubicación (opcional) seleccionada será establecida para todos los usuarios importados.',
    'print_assigned'    => 'Imprimir Todos los Asignados',
    'software_user'     => 'Software Asignado a :name',
    'send_email_help'   => 'Debe proporcionar una dirección de correo electrónico para este usuario para enviarle credenciales. Únicamente pueden enviarse credenciales por correo eléctronico durante la creación del usuario. Las contraseñas se almacenan en un hash de un solo sentido y no se pueden recuperar una vez guardadas.',
    'view_user'         => 'Ver Usuario :name',
    'usercsv'           => 'Archivo CSV',
    'two_factor_admin_optin_help' => 'Tus configuraciones de administrador actuales permiten cumplimiento selectivo de autenticación de dos factores.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA inscrito ',
    'two_factor_active'   => '2FA activo ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
